Varint traits and helpers used by the Lencode scheme.
Structs
Enums
- Lencode
- The Lencode integer encoding scheme is designed to encode integers in a variable‑length format that is efficient for both small and large values both in terms of space and speed.
Traits
- Byte
Length - Trait for types that have a constant representing their byte length.
- Max
- Trait for types that have a constant representing the maximum value.
- Min
- Trait for types that have a constant representing the minimum value.
- One
- Trait for types that have a constant representing the value one.
- OneHundred
Twenty Seven - Trait for types that have a constant representing the value 127.
- Signed
Integer - Trait for all signed integer types supported by this crate.
- ToSigned
- Trait for converting an unsigned integer to its signed equivalent.
- ToUnsigned
- Trait for converting a signed integer to its unsigned equivalent.
- Unsigned
Integer - Trait implemented by all supported unsigned integer types.
- Varint
Encoding Scheme - A trait describing a variable‑length integer and boolean encoding scheme.
- Zero
- Trait for types that have a constant representing the value zero.
Functions
- zigzag_
decode - Decodes an
UnsignedIntegerback into itsSignedIntegerrepresentation using ZigZag encoding. - zigzag_
encode - Encodes a
SignedIntegerinto itsUnsignedIntegerrepresentation using ZigZag encoding.